import React, { useCallback, useState, useEffect } from "react";
import { Pagination, List, Grid, Segment, Loader, Header } from "semantic-ui-react";
import { useGraphQuery } from "../stores";
const renderPlaceholder = (limit) => {
    const output = [];
    for (let i = 0; i < limit; i += 1) {
        const key = `list-placeholder-${i}`;
        output.push(React.createElement(List.Item, { key: key },
            React.createElement(Loader, { active: true, size: "small", inline: "centered" })));
    }
    return output;
};
export const LazyList = ({ entity, item, limit = 20 }) => {
    const [offset, setOffset] = useState(0);
    const [page, setPage] = useState(1);
    const { send: findCount, response: count } = useGraphQuery({
        entity,
        method: "findCount"
    });
    const { send: find, response = [], loading } = useGraphQuery({
        entity,
        method: "find",
        args: [
            {},
            {
                limit,
                offset
            }
        ]
    }, [entity, limit, offset]);
    const onPageChange = useCallback((_, { activePage }) => {
        const p = activePage;
        setPage(p);
        setOffset((p - 1) * limit);
    }, [limit]);
    useEffect(() => {
        const cancel = findCount();
        return cancel;
    }, [entity]);
    useEffect(() => {
        const cancel = find();
        return cancel;
    }, [page, entity]);
    const renderItem = useCallback((r) => React.createElement(List.Item, { as: item, value: r, key: r._id }), [item]);
    let content = null;
    if (loading && !response.length) {
        content = renderPlaceholder(limit);
    }
    else if (!loading && !response.length) {
        content = React.createElement(Header, { content: "No results", textAlign: "center", block: true });
    }
    else {
        content = response.map(renderItem);
    }
    return (React.createElement(Segment, { padded: true },
        React.createElement(List, { divided: true }, content),
        React.createElement(Grid, { centered: true, padded: true },
            React.createElement(Pagination, { disabled: !count, defaultActivePage: page, totalPages: count ? Math.ceil(count / limit) : 1, onPageChange: onPageChange }))));
};
